@@ -1563,6 +1563,7 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 	POOL_SESSION_CONTEXT *session_context;
 	Node *node = NULL;
 	char *query = NULL;
+	bool got_estate = false;
 
 	/*
 	 * It is possible that the "ignore until sync is received" flag was set if
@@ -1733,6 +1734,13 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 			{
 				state = kind;
 			}
+			/*
+			 * However, if the state is 'E', then frontend should had been
+			 * already reported an ERROR. So, to match with that, let be the
+			 * state to be returned to frontend.
+			 */
+			if (kind == 'E')
+				got_estate = true;
 		}
 	}
 
@@ -1744,6 +1752,8 @@ POOL_STATUS ReadyForQuery(POOL_CONNECTION *frontend,
 		{
 			len = htonl(len);
 			pool_write(frontend, &len, sizeof(len));
+			if (got_estate)
+				state = 'E';
 			pool_write(frontend, &state, 1);
 		}
 		pool_flush(frontend);
@@ -3470,7 +3480,7 @@ static void pool_discard_except_sync_and_ready_for_query(POOL_CONNECTION *fronte
 		pmsg = pool_pending_message_head_message();
 		if (pmsg && pmsg->type == POOL_SYNC)
 		{
-			ereport(LOG,
+			ereport(DEBUG1,
 					(errmsg("Process backend response: sync pending message found after receiving error response")));
 			pool_unset_ignore_till_sync();
 			pool_pending_message_free_pending_message(pmsg);
